@@ -235,6 +235,12 @@ class Sheet:
             return None
         return result
 
+    def highlight(self, rows: List[dict], highlight_style: Style):
+        for row in rows:
+            result = self.find(**row)
+            for r in result:
+                self.set_row_style(r, highlight_style)
+
     def filter(self, callback: Callable[[dict], Union[None, bool]]) -> List[dict]:
         data_list = []
 
@@ -480,6 +486,13 @@ class Dataset:
         else:
             return False
 
+    def duplicate(self, name: str, headers_only: bool = False):
+        file = open_file(name)
+        for sheet in self.sheets:
+            sh = sheet.duplicate(sheet.name, headers_only)
+            file.sheets.append(sh)
+        return file
+
     def filter(self, table: Sheet, callback: Callable[[dict], Union[None, bool]]) -> List[dict]:
         return table.filter(callback)
 
